searchData={"items":[{"type":"module","title":"LiveGuard","doc":"A simple module with `on_mount/4` callback. This can used in [Phoenix LiveView](https://hexdocs.pm/phoenix_live_view/Phoenix.LiveView.html#on_mount/1) applications.\nThe main goal is to protect the Phoenix LiveView lifecycle stages easily.\nIt uses the [`attach_hook/4`](https://hexdocs.pm/phoenix_live_view/Phoenix.LiveView.html#attach_hook/4) function to authorize all attachable LiveView lifecycle stages.","ref":"LiveGuard.html"},{"type":"macro","title":"LiveGuard.before_compile_allowed/1","doc":"##","ref":"LiveGuard.html#before_compile_allowed/1"},{"type":"macro","title":"_Optional_ - LiveGuard.before_compile_allowed/1","doc":"This macro can be used with [`@before_compile`](https://hexdocs.pm/elixir/Module.html#module-before_compile) hook.\n\nIt will add a catch-all `allowed?/4` function returning `true`, to the end the module.","ref":"LiveGuard.html#before_compile_allowed/1-_optional_"},{"type":"macro","title":"Example - LiveGuard.before_compile_allowed/1","doc":"```elixir\ndefimpl LiveGuard.Allowed, for: User do\n  @before_compile {LiveGuard, :before_compile_allowed}\n\n  # some code...\nend\n```","ref":"LiveGuard.html#before_compile_allowed/1-example"},{"type":"macro","title":"LiveGuard.before_compile_guarded_stages/1","doc":"##","ref":"LiveGuard.html#before_compile_guarded_stages/1"},{"type":"macro","title":"_Optional_ - LiveGuard.before_compile_guarded_stages/1","doc":"This macro can be used with [`@before_compile`](https://hexdocs.pm/elixir/Module.html#module-before_compile) hook.\n\nIt will add a catch-all `guarded_stages/1` function returning all the [valid attachable LiveView lifecycle stages](https://hexdocs.pm/phoenix_live_view/Phoenix.LiveView.html#attach_hook/4), to the end the module.","ref":"LiveGuard.html#before_compile_guarded_stages/1-_optional_"},{"type":"macro","title":"Example - LiveGuard.before_compile_guarded_stages/1","doc":"```elixir\ndefimpl LiveGuard.GuardedStages, for: Atom do\n  @before_compile {LiveGuard, :before_compile_guarded_stages}\n\n  # some code...\nend\n```","ref":"LiveGuard.html#before_compile_guarded_stages/1-example"},{"type":"function","title":"LiveGuard.on_mount/4","doc":"You can find the documentation of `on_mount/1` [here](https://hexdocs.pm/phoenix_live_view/Phoenix.LiveView.html#on_mount/1).","ref":"LiveGuard.html#on_mount/4"},{"type":"type","title":"LiveGuard.attachable_lifecycle_stages/0","doc":"All the [attachable LiveView lifecycle stages](https://hexdocs.pm/phoenix_live_view/Phoenix.LiveView.html#attach_hook/4).","ref":"LiveGuard.html#t:attachable_lifecycle_stages/0"},{"type":"protocol","title":"LiveGuard.Allowed","doc":"By this protocol you can implement `allowed?/4` functions.","ref":"LiveGuard.Allowed.html"},{"type":"function","title":"LiveGuard.Allowed.allowed?/4","doc":"By this function you can protect the LiveView lifecycle stages.\n\nYou can pattern match by the **user**, **LiveView module**, **LiveView lifecycle stage** and **LiveView lifecycle stage inputs**.\nYou can put this file anywhere but `/lib/my_app_web/live/abilities.ex` is recommended.\n\n**It must return a boolean.**","ref":"LiveGuard.Allowed.html#allowed?/4"},{"type":"function","title":"Example - LiveGuard.Allowed.allowed?/4","doc":"```elixir\n# /lib/my_app_web/live/abilities.ex\n\ndefimpl LiveGuard.Allowed, for: User do\n  @before_compile {LiveGuard, :before_compile_allowed}\n\n  def allowed?(\n        %User{role: role},\n        MyModuleLive,\n        :handle_event,\n        {\"delete_item\", _params, _socket}\n      )\n      when role in [:viewer, :customer],\n      do: false\n\n  # other `allowed?/4` functions...\nend\n```\n> Note: As you can see, you don't have to define catch-all `allowed?/4` function because we used `@before_compile {LiveGuard, :before_compile_allowed}` hook. It returns `true`. This is optional.\n\nIf the user is not authenticated you can add the following implementation as below:\n```elixir\ndefimpl LiveGuard.Allowed, for: Atom do\n  @before_compile {LiveGuard, :before_compile_allowed}\n\n  def allowed?(nil, MyModuleLive, :handle_event, {\"delete_item\", _params, _socket}),\n    do: false\n\n  # other `allowed?/4` functions...\nend\n```","ref":"LiveGuard.Allowed.html#allowed?/4-example"},{"type":"type","title":"LiveGuard.Allowed.t/0","doc":"A user struct or nil when the user is not authenticated.","ref":"LiveGuard.Allowed.html#t:t/0"},{"type":"protocol","title":"LiveGuard.GuardedStages","doc":"##","ref":"LiveGuard.GuardedStages.html"},{"type":"protocol","title":"_Optional_ - LiveGuard.GuardedStages","doc":"By this protocol you can implement `guarded_stages/1` functions.","ref":"LiveGuard.GuardedStages.html#module-_optional_"},{"type":"function","title":"LiveGuard.GuardedStages.guarded_stages/1","doc":"##","ref":"LiveGuard.GuardedStages.html#guarded_stages/1"},{"type":"function","title":"_Optional_ - LiveGuard.GuardedStages.guarded_stages/1","doc":"This function is for optimization.\n\nBy default if you use the `on_mount/4` callback of LiveGuard, it will attach hooks to all attachable LiveView lifecycle stages (`:handle_params`, `:handle_event`, `:handle_info` and `:after_render`).\n\nIf you need to protect for example only the `:handle_event` LiveView lifecycle stage for an individual LiveView module you can use this function.\nYou can put this file anywhere but `/lib/my_app_web/live/guarded_stages.ex` is recommended.\n\n**It must return a list of [valid attachable LiveView lifecycle stages](https://hexdocs.pm/phoenix_live_view/Phoenix.LiveView.html#attach_hook/4).**","ref":"LiveGuard.GuardedStages.html#guarded_stages/1-_optional_"},{"type":"function","title":"Example - LiveGuard.GuardedStages.guarded_stages/1","doc":"```elixir\n# /lib/my_app_web/live/guarded_stages.ex\n\ndefimpl LiveGuard.GuardedStages, for: Atom do\n  @before_compile {LiveGuard, :before_compile_guarded_stages}\n\n  def guarded_stages(MyModuleLive), do: [:handle_event]\n\n  # other `guarded_stages?/1` functions...\nend\n```\nIn this case it will only attach hook to `:handle_event` LiveView lifecycle stage.\n> Note: As you can see, you don't have to define catch-all `guarded_stages/1` function because we used `@before_compile {LiveGuard, :before_compile_guarded_stages}` hook. It returns all the attachable LiveView lifecycle stages. This is optional.","ref":"LiveGuard.GuardedStages.html#guarded_stages/1-example"},{"type":"type","title":"LiveGuard.GuardedStages.t/0","doc":"A LiveView module.","ref":"LiveGuard.GuardedStages.html#t:t/0"},{"type":"module","title":"LiveGuard.Helpers","doc":"Helpers module of LiveGuard.","ref":"LiveGuard.Helpers.html"},{"type":"function","title":"LiveGuard.Helpers.handle_unauthorized/2","doc":"This function handles unauthorized LiveView lifecycle stages.\nIt's called when the [`allowed?/4`](https://hexdocs.pm/live_guard/LiveGuard.Allowed.html#allowed?/4) function returns `false`.\n\nBy default it will put an error flash message with text \"_You don't have permission to do that!_\".\n\n`:mount`, `:handle_params` and `:after_render` LiveView lifecycle stages needs redirect after it detected as unauthorized.\nIn this case by default it will redirect to the home page (`/`).\n\nYou can set a custom handler in the config:\n```elixir\nconfig :live_guard, :unauthorized_handler, {MyModule, :my_handle_unauthorized}\n```\nIt's called with 2 inputs, first is a `socket`, second is `is_redirect` _(boolean)_.","ref":"LiveGuard.Helpers.html#handle_unauthorized/2"},{"type":"extras","title":"LiveGuard","doc":"# LiveGuard\n\nA simple package to protect the LiveView lifecycle stages such as `:mount`, `:handle_params`, `:handle_event`, `:handle_info` and `:after_render`.","ref":"readme.html"},{"type":"extras","title":"Installation - LiveGuard","doc":"For the latest master:\n```elixir\ndef deps do\n  [\n    {:live_guard, github: \"FabianDaniel00/live_guard\"}\n  ]\nend\n```\nFor the latest release:\n```elixir\ndef deps do\n  [\n    {:live_guard, \"~> 0.1.4\"}\n  ]\nend\n```\nThen run `mix deps.get` to fetch the dependencies.","ref":"readme.html#installation"},{"type":"extras","title":"Config - LiveGuard","doc":"- `:current_user`\n\n  You need to assign the current user to the socket.\n  The default assign name for the current user is `:current_user`.\n  If you assign the current user as another than `:current_user` you can set in the config:\n  ```elixir\n  config :live_guard, :current_user, :user\n  ```\n\n- `:unauthorized_handler`\n\n  This function handles unauthorized LiveView lifecycle stages.\n  It's called when the [`allowed?/4`](https://hexdocs.pm/live_guard/LiveGuard.Allowed.html#allowed?/4) function returns `false`.\n\n  By default it will put an error flash message with text \"_You don't have permission to do that!_\".\n\n  `:mount`, `:handle_params` and `:after_render` LiveView lifecycle stages needs redirect after it detected as unauthorized.\n  In this case by default it will redirect to the home page (`/`).\n\n  You can set a custom handler in the config:\n  ```elixir\n  config :live_guard, :unauthorized_handler, {MyModule, :my_handle_unauthorized}\n  ```\n  It's called with 2 inputs, first is a `socket`, second is `is_redirect` _(boolean)_.","ref":"readme.html#config"},{"type":"extras","title":"Usage - LiveGuard","doc":"LiveGuard provide an `on_mount/4` callback which can be used in Phoenix LiveViews. [Read the docs](https://hexdocs.pm/phoenix_live_view/Phoenix.LiveView.html#on_mount/1).\n\nSince this is an `on_mount/1` callback you can use it three ways:\n\n- with [`live_session/3`](https://hexdocs.pm/phoenix_live_view/Phoenix.LiveView.Router.html#live_session/3) to protect a couple of LiveViews lifecycle stages at once:\n  ```elixir\n  # lib/my_app_web/router.ex\n\n  defmodule MyAppWeb.Router do\n    use MyAppWeb, :router\n\n    live_session :default, on_mount: LiveGuard do\n      # routes...\n    end\n  end\n  ```\n- if you want to protect LiveView lifecycle stages in every LiveViews, you can achive that with the following code:\n  ```elixir\n  # lib/my_app_web.ex\n\n  defmodule MyAppWeb do\n    # some code...\n\n    def live_view do\n      quote do\n        use Phoenix.LiveView, layout: {MyAppWeb.Layouts, :app}\n\n        on_mount LiveGuard\n\n        unquote(html_helpers())\n      end\n    end\n\n    # some code...\n  end\n  ```\n- and if you want to protect an individual LiveView lifecycle stages you can achive that with the following code:\n  ```elixir\n  # lib/my_app_web/live/my_module_live.ex\n\n  defmodule MyAppWeb.MyModuleLive do\n    use MyAppWeb, :live_view\n\n    on_mount LiveGuard\n\n    def mount(_params, _session, socket) do\n      {:ok, socket}\n    end\n\n    # some code...\n  end\n  ```\n\n#","ref":"readme.html#usage"},{"type":"extras","title":"Implementation - LiveGuard","doc":"For now you should ask, _okay but how it will know how to protect the LiveView lifecycle stages?_\n\nYou need to implement [`allowed?/4`](https://hexdocs.pm/live_guard/LiveGuard.Allowed.html#allowed?/4) protocol functions.\nThe first input of `allowed?/4` function is the **user**, the second is the **LiveView module**, the third is the **LiveView lifecycle stage** and the last is **LiveView lifecycle stage inputs**. In this way you can pattern match to your needings. You can put this file anywhere but `/lib/my_app_web/live/abilities.ex` is recommended.\n\n**It must return a boolean.**\n\n```elixir\n# /lib/my_app_web/live/abilities.ex\n\ndefimpl LiveGuard.Allowed, for: User do\n  @before_compile {LiveGuard, :before_compile_allowed}\n\n  def allowed?(\n        %User{role: role},\n        MyModuleLive,\n        :handle_event,\n        {\"delete_item\", _params, _socket}\n      )\n      when role in [:viewer, :customer],\n      do: false\n\n  # other `allowed?/4` functions...\nend\n```\n> Note: As you can see, you don't have to define catch-all `allowed?/4` function because we used `@before_compile {LiveGuard, :before_compile_allowed}` hook. It returns `true`. This is optional.\n\nIf the user is not authenticated you can add the following implementation as below:\n```elixir\ndefimpl LiveGuard.Allowed, for: Atom do\n  @before_compile {LiveGuard, :before_compile_allowed}\n\n  def allowed?(nil, MyModuleLive, :handle_event, {\"delete_item\", _params, _socket}),\n    do: false\n\n  # other `allowed?/4` functions...\nend\n```\n\n#","ref":"readme.html#implementation"},{"type":"extras","title":"Optimization _(optional)_ - LiveGuard","doc":"By default if you use the `on_mount/4` callback of LiveGuard, it will attach hooks to all attachable LiveView lifecycle stages (`:handle_params`, `:handle_event`, `:handle_info` and `:after_render`).\nIf you need to protect for example only the `:handle_event` LiveView lifecycle stage for an individual LiveView module you can use this function.\nYou can put this file anywhere but `/lib/my_app_web/live/guarded_stages.ex` is recommended.\n\n**It must return a list of [valid attachable LiveView lifecycle stages](https://hexdocs.pm/phoenix_live_view/Phoenix.LiveView.html#attach_hook/4).**\n\n##","ref":"readme.html#optimization-_-optional-_"},{"type":"extras","title":"Example - LiveGuard","doc":"```elixir\n# /lib/my_app_web/live/guarded_stages.ex\n\ndefimpl LiveGuard.GuardedStages, for: Atom do\n  @before_compile {LiveGuard, :before_compile_guarded_stages}\n\n  def guarded_stages(MyModuleLive), do: [:handle_event]\n\n  # other `guarded_stages?/1` functions...\nend\n```\nIn this case it will only attach hook to `:handle_event` LiveView lifecycle stage.\n> Note: As you can see, you don't have to define catch-all `guarded_stages/1` function because we used `@before_compile {LiveGuard, :before_compile_guarded_stages}` hook. It returns all the valid attachable LiveView lifecycle stages. This is optional.","ref":"readme.html#example"},{"type":"extras","title":"License - LiveGuard","doc":"MIT License. Copyright 2023 Daniel Fabian.","ref":"readme.html#license"},{"type":"extras","title":"Few words from the author - LiveGuard","doc":"[GitHub repository](https://github.com/FabianDaniel00/live_guard)\n\n_This package is inspired by [canary](https://github.com/cpjk/canary)._","ref":"readme.html#few-words-from-the-author"},{"type":"extras","title":"CHANGELOG","doc":"##","ref":"changelog.html"},{"type":"extras","title":"There are no significant changes since the first release. - CHANGELOG","doc":"","ref":"changelog.html#there-are-no-significant-changes-since-the-first-release"}],"content_type":"text/markdown"}